pub struct WriteOpts {
pub indent: Indent,
pub newline: Newline,
}Expand description
Options for controlling how the XML Document is written when serialized.
Fields
indent: IndentThe type of indenting to use when writing the document, i.e. tabs, 2 spaces, 4 spaces.
newline: NewlineThe type of newline to use when writing the document.